package
Version:
v0.0.0-...-19863dc
Opens a new window with list of versions in this module.
Published: Nov 30, 2020
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
InvalidParameters int = 400
Conflict int = 409
NotFound int = 404
ProcessmentError int = 500
InvalidCredentials int = 401
Unknown int = 500
)
type Exception struct {
Message string `json:"message"`
Code int `json:"code"`
Err error `json:"-"`
}
Exception is a struct for error
Source Files
¶
Click to show internal directories.
Click to hide internal directories.